import 'dart:convert';

import 'package:flutter/material.dart';

import '../../../models/statistics_recent.dart';
import '../../../network/scrobbles_api.dart';
import '../../../ui/widgets/error.dart';
import 'statistics_recent_content.dart';

class StatisticsRecentCard extends StatelessWidget {
  const StatisticsRecentCard({super.key});

  @override
  Widget build(BuildContext context) {
    final int daysCount = 21;

    late Future<StatisticsRecentData> future = ScrobblesApi.fetchRecentStatistics(daysCount);

    return FutureBuilder<StatisticsRecentData>(
      future: future,
      builder: (context, snapshot) {
        if (snapshot.hasError) {
          return ShowErrorWidget(message: '${snapshot.error}');
        }

        return Card(
          elevation: 2,
          shadowColor: Theme.of(context).colorScheme.shadow,
          color: Theme.of(context).colorScheme.primary,
          shape: const RoundedRectangleBorder(
            borderRadius: BorderRadius.all(
              Radius.circular(8),
            ),
          ),
          child: Padding(
            padding: const EdgeInsets.all(8.0),
            child: StatisticsRecentContent(
              statistics: snapshot.hasData
                  ? StatisticsRecentData.fromJson(jsonDecode(snapshot.data.toString()))
                  : StatisticsRecentData.createEmpty(),
              isLoading: !snapshot.hasData,
            ),
          ),
        );
      },
    );
  }
}
